@@ -1,12 +1,12 @@
 ﻿
 
 
-__version__ = "0.2020.4.10"
+__version__ = "0.2020.4.11"
 
 
 from .D import D
 from .T1 import T1
 from .T5 import T5
 
-from .dateiterator import dateRange
-from .timeiterator5 import timeRange5
+from .dateiterator import dateRange, dateRangeI
+from .timeiterator5 import timeRange5
\ No newline at end of file
